@@ -1,9 +1,5 @@
-# builtin modules
-import sys
-
 # pyqt modules
-from PyQt4.QtGui import (QApplication, QLabel, QPushButton, 
-                          QMainWindow, QVBoxLayout, QWidget)
+from PyQt4.QtGui import (QMainWindow)
 from PyQt4.QtCore import (Qt)
 
 # third-party modules
@@ -15,7 +11,7 @@ from ui.ui_meals_window import Ui_MealsWindow
 class MealsWindow(QMainWindow, Ui_MealsWindow):
 
     def __init__(self, parent=None, database=None):
-        super(QMainWindow, self).__init__(parent)
+        super(MealsWindow, self).__init__(parent)
         self.setAttribute(Qt.WA_Maemo5StackedWindow)
 
         self.setupUi(self)
