@@ -60,11 +60,11 @@ class WelcomeWindow(QMainWindow, Ui_WelcomeWindow):
 
     def setOrientation(self):
         if self.config.interface['orientation'].lower() == 'auto':
-            self.setAttribute(Qt.WA_Maemo5AutoOrientation)
+            self.setAttribute(Qt.WA_Maemo5AutoOrientation, True)
         elif self.config.interface['orientation'].lower() == 'landscape':
-            self.setAttribute(Qt.WA_Maemo5LandscapeOrientation)
+            self.setAttribute(Qt.WA_Maemo5LandscapeOrientation, True)
         elif self.config.interface['orientation'].lower() == 'portrait':
-            self.setAttribute(Qt.WA_Maemo5PortraitOrientation)
+            self.setAttribute(Qt.WA_Maemo5PortraitOrientation, True)
 
     def setFitnessWindow(self):
         if self.config.interface['remember-last-fitness']:
